import { AcceptedPlugin, Parse, Syntax } from 'postcss';
/**
 * Plugin options.
 */
export interface PluginOptions {
    /**
     * The root directory where to resolve path.
     */
    root: string;
    /**
     * Directory (or directories) in which to recursively look for modules.
     */
    moduleDirectory: string | string[];
    /**
     * Paths array to use if nothing is found on the normal node_modules
     * recursive walk.
     */
    paths: string | string[];
    /**
     * PostCSS plugins to be applied on each imported files.
     */
    plugins: AcceptedPlugin[];
    /**
     * PostCSS parsers by file extension.
     */
    parsers: {
        [key: string]: Parse | Syntax;
    };
    /**
     * Custom path resolver.
     *
     * @param uri URI from import rule.
     * @param basedir Base directory for current import.
     * @param options Import options.
     */
    resolve?(uri: string, basedir: string, options: PluginOptions): string | Promise<string>;
}
/**
 * PostCSS plugin.
 */
declare const importPart: import("postcss").Plugin<Partial<PluginOptions>>;
/**
 * Module.
 */
export { importPart as default, };
