"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const postcss_1 = require("postcss");
const getCssBaseDir_1 = __importDefault(require("./getCssBaseDir"));
const parseParams_1 = __importDefault(require("./parseParams"));
const readStylesFile_1 = __importDefault(require("./readStylesFile"));
const resolveUri_1 = __importDefault(require("./resolveUri"));
/**
 * Name of this plugin.
 */
const PLUGIN_NAME = 'postcss-import-part';
/**
 * Name of the plugin At-Rule.
 */
const RULE_NAME = 'import-part';
/**
 * Default plugin options.
 */
const DEFAULT_OPTIONS = {
    root: process.cwd(),
    moduleDirectory: [
        'web_modules',
        'node_modules',
    ],
    paths: [],
    plugins: [],
    parsers: {},
};
/**
 * PostCSS plugin to import variables from JSON file.
 *
 * @param userOptions Plugin options.
 */
function main(userOptions = {}) {
    const options = Object.assign({}, DEFAULT_OPTIONS, userOptions);
    options.root = path_1.resolve(options.root);
    options.paths = (Array.isArray(options.paths)
        ? options.paths
        : [options.paths]).map((path) => path_1.resolve(options.root, path));
    const resultPromises = [];
    const onAtRule = (rule, result) => {
        let params;
        try {
            params = parseParams_1.default(rule.params);
        }
        catch (error) {
            throw rule.error(error.message, { plugin: PLUGIN_NAME });
        }
        const onError = (error) => {
            throw rule.error(error.message, { plugin: PLUGIN_NAME });
        };
        const onContent = (content) => {
            rule.parent.insertAfter(rule, content.clone());
            rule.remove();
        };
        const promise = resolveUri_1.default(params.uri, getCssBaseDir_1.default(rule) || options.root, options)
            .then((path) => readStylesFile_1.default(path, result, options))
            .then(onContent)
            .catch(onError);
        resultPromises.push(promise);
    };
    return (root, result) => {
        root.walkAtRules(RULE_NAME, (rule) => onAtRule(rule, result));
        return Promise.all(resultPromises);
    };
}
/**
 * PostCSS plugin.
 */
const importPart = postcss_1.plugin(PLUGIN_NAME, main);
exports.default = importPart;
//# sourceMappingURL=index.js.map