"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = require("path");
const postcss_1 = __importDefault(require("postcss"));
const util_1 = require("util");
const readFile = util_1.promisify(fs_1.default.readFile);
const stat = util_1.promisify(fs_1.default.stat);
/**
 * Cached file contents.
 */
const cache = new Map();
/**
 * Read content from styles file.
 *
 * @param path Path to styles file.
 */
async function readStylesFile(path, postcssResult, options) {
    const absolutePath = path_1.resolve(path);
    const fileStats = await stat(absolutePath);
    const item = cache.get(absolutePath);
    if (item
        && (item.mtime.getTime() === fileStats.mtime.getTime())) {
        return Promise.resolve(item.content);
    }
    const fileContents = await readFile(absolutePath, 'utf8');
    const extension = path_1.extname(path);
    const parser = options.parsers[extension] || null;
    const result = postcss_1.default(options.plugins).process(fileContents, {
        from: absolutePath,
        parser,
    });
    if (!result.root) {
        throw new Error(`Empty import root in "${absolutePath}".`);
    }
    cache.set(absolutePath, {
        mtime: fileStats.mtime,
        content: result.root,
    });
    if (postcssResult && Array.isArray(postcssResult.messages)) {
        postcssResult.messages = postcssResult.messages.concat(result.messages);
    }
    return result.root;
}
exports.default = readStylesFile;
//# sourceMappingURL=readStylesFile.js.map