"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const resolve_1 = __importDefault(require("resolve"));
/**
 * Path resolver.
 *
 * @param uri URI from import rule.
 * @param basedir Base directory for current import.
 * @param options Import options.
 */
function resolveUri(uri, basedir, options) {
    const onCustomResolve = (path) => {
        if (path_1.isAbsolute(path)) {
            return path;
        }
        const resolveOptions = {
            basedir,
            moduleDirectory: options.moduleDirectory,
            paths: options.paths,
            extensions: ['.css'],
            packageFilter,
        };
        return new Promise((resolve, reject) => {
            resolve_1.default(path, resolveOptions, (error, resolved) => (error
                ? reject(error)
                : resolve(resolved)));
        });
    };
    return Promise.resolve(options.resolve
        ? options.resolve(uri, basedir, options)
        : uri)
        .then(onCustomResolve);
}
exports.default = resolveUri;
/**
 * Process package data to update main file value.
 *
 * @param data Package data.
 */
function packageFilter(data) {
    if (data.style) {
        data.main = data.style;
    }
    else if (!data.main
        || !/\.css$/.test(data.main)) {
        data.main = 'index.css';
    }
    return data;
}
//# sourceMappingURL=resolveUri.js.map